'use strict';

var _rollupPluginBabelHelpers = require('./internal/_rollupPluginBabelHelpers.js');

/**
 * A isEqual to B
 * @param {Any} left
 * @param {Any} right
 */
var isEqual = function isEqual(left, right) {
  if (_rollupPluginBabelHelpers._typeof(left) !== _rollupPluginBabelHelpers._typeof(right)) return false; // both left and right are NaN
  // eslint-disable-next-line no-self-compare

  if (left !== left && right !== right) return true;
  if (_rollupPluginBabelHelpers._typeof(left) !== 'object' && _rollupPluginBabelHelpers._typeof(right) !== 'object') return left === right;

  if (Array.isArray(left) && Array.isArray(right)) {
    if (left.length !== right.length) return false;
    return left.every(function (leftItem, index) {
      return isEqual(leftItem, right[index]);
    });
  }

  var leftKeys = Object.keys(left);
  var rightKeys = Object.keys(right);
  if (leftKeys.length !== rightKeys.length) return false;
  return leftKeys.every(function (key) {
    return right.hasOwnProperty(key) && isEqual(left[key], right[key]);
  });
};

module.exports = isEqual;
